#
# spec file for package mumble
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# requires libzeroc-ice, not available yet
%bcond_without ice
%bcond_without jack
%bcond_without pulseaudio
%bcond_without system_opus
%bcond_without system_speex
# mumble must be able to talk to other clients which may use
# different versions of celt. Since each celt release is
# incompatible to each other mumble bundles some specific
# versions.
%bcond_with     system_celt
Name:           mumble
Version:        1.4.230
Release:        bp154.1.55
Summary:        Voice Communication Client for Gamers
# For Legal: the bundled opus and speex subdirectories are not built.
# Most files are BSD-3-Clause, celt also contains BSD-2-Clause files.
License:        BSD-2-Clause AND BSD-3-Clause
Group:          Productivity/Multimedia/Sound/Utilities
URL:            http://mumble.sourceforge.net/
Source:         https://github.com/mumble-voip/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/mumble-voip/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz.sig
Source3:        murmur.apparmor
# http://mumble.info/gpg/gpg.txt
Source4:        https://raw.githubusercontent.com/mumble-voip/mumble-gpg-signatures/master/mumble-auto-build-2022.asc#/%{name}.keyring
Source5:        mumble-server.service
Source6:        baselibs.conf
BuildRequires:  cmake >= 3.15
BuildRequires:  gcc-c++
BuildRequires:  libcap-devel
BuildRequires:  libogg-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libspeechd-devel
BuildRequires:  protobuf-devel
Requires:       lsb-release
BuildRequires:  libboost_headers-devel
BuildRequires:  pkgconfig(avahi-compat-libdns_sd)
%if %{with system_celt}
BuildRequires:  libcelt-devel
Requires:       libcelt0 > 0.7.0
%endif
%if %{with system_opus}
BuildRequires:  pkgconfig(opus)
%endif
%if %{with system_speex}
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)
%endif
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(PocoZip)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5TextToSpeech)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libopenssl)
BuildRequires:  pkgconfig(xi)
%if %{with ice}
BuildRequires:  pkgconfig(ice)
%endif
%if %{with pulseaudio}
BuildRequires:  pulseaudio-devel
%endif
%if %{with jack}
BuildRequires:  libjack-devel
%endif
%ifarch x86_64
BuildRequires:  gcc-c++-32bit
Recommends:     %{name}-32bit
Conflicts:      %{name}-32bit < %{version}
%endif
%ifarch ppc
Recommends:     %{name}-64bit
Conflicts:      %{name}-64bit < %{version}
%endif
#
%if 0%{?snapshot:1}
Conflicts:      mumble < %{version}
Provides:       mumble = %{version}
%endif
#

%description
Low-latency, high-quality voice communication for gamers. Includes game
linking, so voice from other players comes from the direction of their
characters, and has echo cancellation so the sound from your loudspeakers
won't be audible to other players.

%package server
Summary:        Voice Communication Server for Gamers
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       lsb-release
Requires(pre):  %{_sbindir}/useradd
Recommends:     libQt5Sql5-sqlite
Recommends:     libQt5Sql5-mysql
Recommends:     libQt5Sql5-postgresql
%if 0%{?snapshot:1}
Conflicts:      mumble-server < %{version}
Provides:       mumble-server = %{version}
%endif
%{?systemd_requires}

%description server
Low-latency, high-quality voice communication for gamers. Includes game
linking, so voice from other players comes from the direction of their
characters, and has echo cancellation so the sound from your loudspeakers
won't be audible to other players.

%prep
%setup -q -n %{name}-%{version}.src

%build
%cmake .. \
        -Dupdate:BOOL=OFF \
        -Dsymbols:BOOL=ON \
        -Dcrash-report:BOOL=OFF \
        -DMUMBLE_INSTALL_PLUGINDIR=%{_libdir}/mumble/plugins \
        -DCMAKE_MODULE_LINKER_FLAGS="" \
        -DCMAKE_SHARED_LINKER_FLAGS="" \
%if 1
        -Dice=OFF \
%endif
%if %{with system_celt}
        -Dbundled-celt:BOOL=OFF \
%endif
%if %{with system_speex}
        -Dbundled-opus:BOOL=OFF \
%endif
%if %{with system_speex}
        -Dbundled-speex:BOOL=OFF \
%endif
%if !%{with pulseaudio}
        -Dpulseaudio:BOOL=OFF \
%endif

# build fails for high -j so we overwrite with 1 here
%make_build -j1

%install
%cmake_install

install -D -m 0640 scripts/murmur.ini %{buildroot}%{_sysconfdir}/mumble-server.ini
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -a scripts LICENSE README.md %{buildroot}%{_docdir}/%{name}
find %{buildroot}%{_docdir}/%{name}/scripts -type f -name '*.py' -exec chmod -x {} \;
find %{buildroot}%{_docdir}/%{name}/scripts -type f -name '*.rb' -exec chmod -x {} \;
find %{buildroot}%{_docdir}/%{name}/scripts -type f -name '*.sh' -exec chmod -x {} \;
find %{buildroot}%{_docdir}/%{name}/scripts -type f -name '*.bat' -exec chmod -x {} \;
# Server
##
mkdir -p %{buildroot}%{_tmpfilesdir}
cat >> %{buildroot}%{_tmpfilesdir}/mumble-server.conf <<EOF
d %{_localstatedir}/run/mumble-server 0755 mumble-server mumble-server -
EOF
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/apparmor.d/usr.sbin.murmurd
install -D -m 0644 %{SOURCE5} %{buildroot}%{_unitdir}/mumble-server.service
install -D -m 0644 scripts/murmur.conf %{buildroot}%{_sysconfdir}/dbus-1/system.d/mumble-server.conf
install -D -m 0644 scripts/murmur.ini %{buildroot}%{_sysconfdir}/mumble-server.ini

%pre server
getent group mumble-server >/dev/null || groupadd -r mumble-server || :
getent passwd mumble-server >/dev/null || \
	%{_sbindir}/useradd -r -d %{_localstatedir}/lib/mumble-server -s /bin/false -c "Mumble VoIP Server" -g mumble-server mumble-server 2> /dev/null || :
%service_add_pre mumble-server.service

%preun server
%service_del_preun mumble-server.service

%post server
systemd-tmpfiles --create %{_tmpfilesdir}/mumble-server.conf || true
%service_add_post mumble-server.service

%postun server
%service_del_postun mumble-server.service

%files
%exclude %{_docdir}/%{name}/scripts/murmur.ini
%exclude %{_docdir}/%{name}/scripts/org.mumble_voip.mumble.desktop
%doc %{_docdir}/%{name}
%{_bindir}/mumble
%{_bindir}/mumble-overlay
%{_mandir}/man1/mumble-overlay.*
%{_mandir}/man1/mumble.*
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps
%{_datadir}/icons/hicolor/*/apps/mumble.*
%{_datadir}/applications/*
%{_libdir}/mumble

%files server
%doc %{_docdir}/%{name}/scripts/murmur.ini
%{_bindir}/mumble-server
%config %{_sysconfdir}/dbus-1/system.d/mumble-server.conf
%config(noreplace) %{_sysconfdir}/mumble-server.ini
%{_tmpfilesdir}/mumble-server.conf
%{_unitdir}/mumble-server.service
%{_mandir}/man1/murmurd.*
%{_mandir}/man1/murmur-user-wrapper.*
%{_datadir}/metainfo/org.mumble_voip.mumble.appdata.xml
%dir %{_sysconfdir}/apparmor.d
%config %{_sysconfdir}/apparmor.d/usr.sbin.murmurd

%changelog
* Tue Jan 25 2022 Markus Ebner <info@ebner-markus.de>
- Update to Mumble 1.4.230
  * qmake build-system removed
  * New extended plugin framework
  * Support for stereo playback
  * Support for local naming (nicknames)
  * Markdown support for chat
  * UI indication for access restriction
  * New non-gaming oriented TalkingUI
  * Channel listeners
  * Search dialog for users in a server
- Cleanup of the specfile
  * Fixed source urls for changed scheme
  * Ported specfile to CMake build-system
  * Use cmake install instead of manual as much as possible
  * Disabled ICE for now (depends on unavailable lib)
  * Removed a lot of obsolete logical branches
  * bonjour is no longer optional
  * Removed init.d script and enabled systemd
* Wed Nov 10 2021 Mia Herkt <mia@0x0.st>
- Enable JACK support
* Thu Oct  7 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * mumble-server.service
* Fri Feb 12 2021 Andreas Stieger <andreas.stieger@gmx.de>
- mumble 1.3.4:
  * Fix use of outdated (non-existent) notification icon names
  * Fix Security vulnerability caused by allowing non http/https
    URL schemes in public server list (boo#1182123, CVE-2021-27229)
  * Server: Fix Exit status for actions like --version or --supw
  * Fix packet loss & audio artifacts caused by OCB2 XEX*
    mitigation
- update signing keyring
* Fri Dec 25 2020 Yaroslav Kurlaev <yaroslav.kurlaev@gmail.com>
- Don't edit categories of .desktop files.
  * Fixes boo#1180068
* Sat Oct 24 2020 Marcus Rueckert <mrueckert@suse.de>
- update apparmor profiles to get warning free again on 15.2
  - use abstractions for ssl files
  - allow inet dgram sockets as mumble can also work via udp
  - allow netlink socket (probably for dbus)
  - properly allow lsb_release again
  - add support for optional local include
- start murmurd directly as user mumble-server it gets rid of the
  dac_override/setgid/setuid/chown permissions
* Mon Oct  5 2020 Markus Ebner <info@ebner-markus.de>
- Update to upstream version 1.3.3
- Client
  * Fixed: Chatbox invisble (zero height) (#4388)
  * Fixed: Handling of invalid packet sizes (#4394)
  * Fixed: Race-condition leading to loss of shortcuts (#4430)
  * Fixed: Link in About dialog is now clickable again (#4454)
  * Fixed: Sizing issues in ACL-Editor (#4455)
  * Improved: PulseAudio now always samples at 48 kHz (#4449)
- Server
  * Fixed: Crash due to problems when using PostgreSQL (#4370)
  * Fixed: Handling of invalid package sizes (#4392)
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Consistently use %%{_tmpfilesdir} instead of abusing
  %%{_libexecdir}/tmpfiles.d.
* Sat Jul 11 2020 Andreas Stieger <andreas.stieger@gmx.de>
- mumble 1.3.2:
  * client: Fixed overlay not starting
- fetch upstream release signing key for 2020
* Fri Jun 19 2020 UTC - Markus Ebner <info@ebner-markus.de>
- Update to upstream version 1.3.1
- Security
  * Fixed: Potential exploit in the OCB2 encryption (#4227)
    boo#1174041
- ICE
  * Fixed: Added missing UserKDFIterations field to UserInfo =>
    Prevents getRegistration() from failing with enumerator
    out of range error (#3835)
- GRPC
  * Fixed: Segmentation fault during murmur shutdown (#3938)
- Client
  * Fixed: Crash when using multiple monitors (#3756)
  * Fixed: Don't send empty message from clipboard via shortcut,
    if clipboard is empty (#3864)
  * Fixed: Talking indicator being able to freeze to indicate talking
    when self-muted (#4006)
  * Fixed: High CPU usage for update-check if update server not
    available (#4019)
  * Fixed: DBus getCurrentUrl returning empty string when not in
    root-channel (#4029)
  * Fixed: Small parts of whispering leaking out (#4051)
  * Fixed: Last audio frame of normal talking is sent to last
    whisper target (#4050)
  * Fixed: LAN-icon not found in ConnectDialog (#4058)
  * Improved: Set maximal vertical size for User Volume Adjustment
    dialog (#3801)
  * Improved: Don't send empty data to PulseAudio (#3316)
  * Improved: Use the SRV resolved port for UDP connections (#3820)
  * Improved: Manual Plugin UI (#3919)
  * Improved: Don't start Jack server by default (#3990)
  * Improved: Overlay doesn't hook into all other processes by
    default (#4041)
  * Improved: Wait longer before disconnecting from a server due
    to unanswered Ping-messages (#4123)
- Server
  * Fixed: Possibility to circumvent max user-count
    in channel (#3880)
  * Fixed: Rate-limit implementation susceptible to
    time-underflow (#4004)
  * Fixed: OpenSSL error 140E0197 with Qt >= 5.12.2 (#4032)
  * Fixed: VersionCheck for SQL for when to use the
    WAL feature (#4163)
  * Fixed: Wrong database encoding that could lead
    to server-crash (#4220)
  * Fixed: DB crash due to primary key violation
    (now performs "UPSERT" to avoid this) (#4105)
  * Improved: The fields in the Version ProtoBuf message are
    now size-restricted (#4101)
- Drop patch add-speechd-include-path.patch, included upstream
* Wed Apr 15 2020 Marcus Rueckert <mrueckert@suse.de>
- use the "profile profilename /path/to/binary" syntax to make
  "ps aufxZ" more readable
* Wed Nov  6 2019 opensuse@trummer.xyz
- set permissions of config file to 640 because it can contain passwords
* Wed Sep 11 2019 Christophe Giboudeaux <christophe@krop.fr>
- Really use the system speex and opus dependencies.
- Run spec-cleaner, use pkgconfig() style BuildRequires when possible.
- Fix the package requirements.
- Remove obsolete conditions and build options.
- Also recommend the Qt mysql and psql backend. Murmur also supports
  those drivers.
* Tue Sep 10 2019 Michal Suchanek <msuchanek@suse.de>
- Update to upstream version 1.3.0 final.
  Release notes at:
    https://www.mumble.info/blog/mumble-1.3.0-release-announcement/
- Use system speex and opus.
* Tue Sep  3 2019 Michal Suchanek <msuchanek@suse.de>
- Update to upstream version 1.3.0-rc2. Supports Qt5. (boo#1148406)
- Remove upstreamed patches:
  - 0001-AudioOutput-do-not-use-non-existant-template-version.patch
  - appdata.patch
  - initialize-soundfile-format.patch
  - mumble-1.2.2-buildcompare.diff
  - mumble-1.2.11-desktop_fix.diff
  - mumble-1.2.19-limit-amount-of-messages.patch
  - mumble-1.2.19-stricter-message-limit.patch
  - mumble-pr-3623-protobuf37.patch
- Refresh add-speechd-include-path.patch
* Fri Jul 12 2019 Ferdinand Thiessen <rpm@fthiessen.de>
- Added patches to fix boo#1123334 (CVE-2018-20743), instability
  and crash due to crafted message flooding
  * added mumble-1.2.19-limit-amount-of-messages.patch (backported
    version of upstream patch)
  * added mumble-1.2.19-stricter-message-limit.patch (backported
    version of upstream patch)
- Cleaned spec file, removed old EOL openSUSE and Fedora versions
* Wed Jun 26 2019 Dirk Mueller <dmueller@suse.com>
- add mumble-pr-3623-protobuf37.patch to fix build against protobuf 3.7
* Wed Jun  5 2019 Ismail Dönmez <idonmez@suse.com>
- Add add-speechd-include-path.patch to fix speechd include paths
- Enable speechd everywhere now
* Sun Apr 14 2019 Christian Boltz <suse-beta@cboltz.de>
- update murmurd AppArmor profile
  - update bash path for usrMerge (boo#1132350)
  - use abstractions/openssl instead of a rule for openssl.cnf
* Fri Oct 19 2018 Marguerite Su <i@marguerite.su>
- build with -std=c++1z on TW since it applies -Wfatal-error that
  conflicts with -std=c++98
* Wed Jan  3 2018 kwalter@suse.com
- Add 0001-AudioOutput-do-not-use-non-existant-template-version.patch
  to fix tumbleweed compilation
* Thu Jun  8 2017 alarrosa@suse.com
- Add initialize-soundfile-format.patch to initilalize a variable so
  it's not used later uninitialized.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sun Jan 29 2017 mailaender@opensuse.org
- update to 1.2.19:
  * Murmur’s -limits command will now print output as it runs, instead of at exit.
* Mon Dec 19 2016 dmueller@suse.com
- update to 1.2.18:
  - mostly non-Linux fixes
  - switch default compiler to use C++03
* Sun Sep 25 2016 mailaender@opensuse.org
- Update to version 1.2.17
  * Fixed a bug that could cause the Mumble log view to be
    inacessible after receiving a specially crafted text message.
  * The PulseAudio backend will now fall back to default device
    if the chosen device is no longer present.
  * Mumble now explicitly sends plain text notifications to KDE
    and Freedesktop.org notification endpoints.
  * Xbox button/controller names as shown by Mumble should now be
    correct for controllers other than the first controller.
- Add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
* Fri May 13 2016 rpm@fthiessen.de
- Fixed build on 13.1 by only adding (/var)/run/mumble-server
  as temporary file only on newer openSUSE versions (> 1310)
* Fri May  6 2016 mailaender@opensuse.org
- mumble 1.2.16
  * Mumble will no longer try to poll for changes in XInput button
    state when no controllers are connected.
  * The last references (public server list registration and crash
    reporting) to the old domain name for the Mumble service host,
    “mumble.hive.no”, have been changed to use “mumble.info” instead.
  * The overlay blacklist from 1.3.0 snapshots has been backported.
- add (/var)/run/mumble-server as temporary file for proper cleanup
* Sun Mar 13 2016 astieger@suse.com
- mumble 1.2.15:
  * Add ability to disable the public server list
  * Add ability to create and/or edit Mumble’s server list
- includes changes from 1.2.14:
  * Fix regression crash on exit for in overlay feature
* Mon Jan 11 2016 astieger@suse.com
- mumble 1.2.13:
  * Fix Murmur DoS (Mumble-SA-2016-001), does not affect GNU/Linux
- update upstream signing keyring
* Mon Jan  4 2016 astieger@suse.com
- mumble 1.2.12:
  * The log would always scroll-to-bottom, even if manually
    scrolled up to view a previous message. Scroll-to-bottom is now
    only triggered if the log view has not manually scrolled by the
    user.
  * Fixed a bug where a stale overlay client could cause the Mumble
    UI to freeze under some circumstances.
  * Fixed a bug where CELT and Opus encoders were not properly
    reset when using more than one frame per packet in Mumble. This
    would previously cause noisy artifacts at the beginning of
    transmissions.
* Mon Dec 14 2015 rpm@fthiessen.de
- Removed unneeded patch for SLE10: mumble-1.1.4-sle10glx.diff
- Added patch from RandyBB (roman@priesol.net) to fix missing
  semicolons in desktop file: mumble-1.2.11-desktop_fix.diff
- Removed parts for outdated openSUSE versions, older then openSUSE
  12.2 or SLE 11, from spec file
* Mon Dec 14 2015 astieger@suse.com
- update to 1.2.11:
  * Fixed a bug where Mumble global shortcuts on X11 would not
    release properly when Chrome/Chromium was the frontmost application.
  * Fixed a bug where clients would automatically reconnect after
    being kicked.
  * Inserting an image in the chat should now always cause Mumble
    to scroll correctly to the bottom of the log.
  * Opening mumble:// URLs should now correctly allow people to
    change channels if a URL is opened while Mumble is running.
  * Fixed an issue where the “shortcut/linux/evdev/enable” config
    option was not saved correctly, and overwritten when closing
    Mumble.
* Tue Oct 13 2015 astieger@suse.com
- update to 1.2.10:
  * no code change, other than to create another binary release
    for platforms other than GNU/Linux with updated libraries
* Thu Jun 18 2015 mailaender@opensuse.org
- update to 1.2.9 maintenance release
- remove redundant clean section
- add missing service_add_pre macro
- gpg key has changed
* Wed Mar 18 2015 rpm@fthiessen.de
- Added speech-dispatcher support for openSUSE (Text-To-Speech)
* Mon Mar 16 2015 dimstar@opensuse.org
- Add pkgconfig(speexdsp) BuildRequires: its presence is checked
  for by the build system.
* Thu Feb  5 2015 lnussel@suse.de
- remove gpg-offline from BuildRequires, now done by source validator
  automatically
* Fri Nov 21 2014 lnussel@suse.de
- fix murmur-user-wrapper (bnc#906416)
* Sat Aug  9 2014 mailaender@opensuse.org
- update to 1.2.8
  + A PulseAudio issue that could cause the Mumble client
    to crash on launch has been fixed.
  + Various source-level issues that made the Mumble build
    fail when built with Clang has been fixed.
* Tue Jul 29 2014 mrueckert@suse.de
- fix build for older distros like SLE 11
  - disable xinput2 support on sle 11
  - add a new bcond for systemd and use that throughout the spec
    file for guarding systemd usage instead of spreading out the
    if suse_version conditional all over the place.
  - some systemd pieces were also done on none systemd distros.
    move those into the systemd blocks.
* Sat Jun 14 2014 mailaender@opensuse.org
- update to 1.2.7, minor bugfix
* Thu May 15 2014 lnussel@suse.de
- new bugfix release 1.2.6 fixes security issues (CVE-2014-3756,
  bnc#877971, CVE-2014-3755, bnc#877969)
* Wed Mar 26 2014 lnussel@suse.de
- enable rc link also for systemd
* Thu Feb  6 2014 lnussel@suse.de
- new version 1.2.5 fixes security issues (CVE-2014-0044, CVE-2014-0045,
  bnc#862527)
* Sat Jan 11 2014 adler_187@yahoo.com
- remove syslog.target, since it no longer exists in recent
  systemd versions (>202) and causes the service to fail to start
  (bnc#855478)
* Thu Aug  1 2013 lnussel@suse.de
- clean up old macros
* Thu Jun  6 2013 pascal.bleser@opensuse.org
- update to 1.2.4: http://mumble.sourceforge.net/1.2.4
  Obsoleted patches:
  0001-fix-build-error-with-capability.h.diff
  0001-fix-user-switching.diff
  0001-open-log-file-early-so-log-dir-can-be-root-owned.diff
  0001-if-service-name-is-empty-don-t-pass-an-empty-string.diff
  0001-remove-CAP_NET_ADMIN.diff
  0001-fix-bonjour-support-using-avahi-compat-lib.diff
  mumble-1.2.3-nohardcodedcas.diff
  0001-Explicitly-remove-file-permissions-for-settings-and-D.diff
- systemd service file
* Wed Nov 28 2012 sbrabec@suse.cz
- Verify GPG signature.
* Wed Nov  7 2012 opensuse@cboltz.de
- install apparmor profile without x permissions
* Wed Nov  7 2012 lnussel@suse.de
- require lsb-release (bnc#785659)
* Mon Jun 25 2012 lnussel@suse.de
- allow reading /etc/ssl/openssl.cnf in apparmor profile (bnc#768692)
- fix path to sed and grep due to usr move in 12.2
* Mon Feb 20 2012 lnussel@suse.de
- remove read permissions for other users on local sqlite database
  as it may contain passwords (bnc#747833, CVE-2012-0863)
* Mon Feb 13 2012 lnussel@suse.de
- don't add built-in CA certificates (bnc#660784)
* Wed Jul  6 2011 aj@suse.de
- Use /usr/lib/tmpfiles.d instead of /etc/tmpfiles.d.
* Sat Jun 11 2011 lnussel@suse.de
- install mumble in libdir and put a symlink in bindir to make
  loading libs from applicationDirPath work.
* Mon Apr 11 2011 lnussel@suse.de
- fix bonjour support
* Sun Apr  3 2011 lnussel@suse.de
- fix plugin path
* Thu Mar 24 2011 lnussel@suse.de
- add apparmor profile
* Wed Mar 23 2011 lnussel@suse.de
- fix bonjour registration
* Tue Mar  8 2011 lnussel@suse.de
- change log dir owner to root
- clean up init script
* Mon Feb 21 2011 lnussel@suse.de
- avoid duplicate libcelt libs
* Mon Feb 21 2011 lnussel@suse.de
- new version 1.2.3
  - Improved Voice Activity Detection
  - Customizable Overlay with FPS counter
  - Recording
  - Priority speaker
  - Updated CELT Codec to version 0.11.0
* Thu Jan 27 2011 lnussel@suse.de
- change license tag to BSD3c (bnc#667547)
* Thu Dec 23 2010 lnussel@suse.de
- fix build on sle11sp1
* Wed Dec 15 2010 lnussel@suse.de
- fix some rpmlint warnings
* Fri Jul 16 2010 lnussel@suse.de
- fix crash with long user names (CVE-2010-2490)
* Fri Apr 23 2010 lnussel@suse.de
- actually enable pulseaudio
* Wed Feb 10 2010 lnussel@suse.de
- new version 1.2.2
  * new user information dialog
  * new toolbar
  * Improved connect speed to large servers with lots of users and comments (needs updated server) through use of local caching of content
  * Servers using trusted certificates are now highlighted in green throughout the GUI.
  * CELT version bump; possible quality improvements as a result, on certain configurations
  * LOTRO, L4D2, and ArmA2 plugins
  * Replaced user-textures with avatars to make overlay more useful
  * Better overlay system on Win32 using the pipe method
  * Numerous GUI improvements, including consolidating and reorganizing the main window menus
  * Logitech G15 fixes and improvements
  * Made friend and server window icons skinnable (emblem-favorite.svg, etc, see Skinning)
  * server side database upgrade bug (only occured when updating from 1.1.8 directly to 1.2.1)
  * Bonjour LAN server discovery and resolving works again
  * G15 activation problems
  * memory leak on certain configurations
* Wed Jan 13 2010 lnussel@suse.de
- libcelt must be in /usr/lib/mumble rather than /usr/lib/mumble/plugins
* Sun Jan 10 2010 lnussel@suse.de
- enable ice for fedora 12
* Sun Jan 10 2010 lnussel@suse.de
- add patch to fix 1.1.8 ->  1.2.1 server migration
* Sat Jan  9 2010 lnussel@suse.de
- new version 1.2.0
- add init script and user for server
* Sat Dec 12 2009 lnussel@suse.de
- fix certificate wizard page order for Qt 4.4
* Fri Dec 11 2009 lnussel@suse.de
- new version 1.2.0
* Tue Jul 28 2009 lnussel@suse.de
- fix gcc warning in overlay_gl that causes build failure in Factory
* Mon Mar 30 2009 lnussel@suse.de
- force use of bundled speex on 11.0 to fix build
* Fri Mar 27 2009 lnussel@suse.de
- new version 1.1.8
* Tue Feb 24 2009 lnussel@suse.de
- mark server config as %%config
* Mon Feb 23 2009 lnussel@suse.de
- new version 1.1.7
* Sun Jan 25 2009 lnussel@suse.de
- filter glibc private symbols
- cleanup
* Sat Jan 17 2009 lnussel@suse.de
- add experimental patch to not use mice for shortcuts
* Fri Sep 19 2008 lnussel@suse.de
- new version 1.1.6
* Fri Sep  5 2008 lnussel@suse.de
- enable pulseaudio on openSUSE
- change requirement for 10.3 qt4 bug workaround
* Sat Jun  7 2008 anschneider@suse.de
- support openSUSE 10.2
* Tue May 13 2008 lnussel@suse.de
- new version 1.1.4
  * now with link plugin
* Wed Mar 19 2008 lnussel@suse.de
- split off server package
* Fri Mar 14 2008 lnussel@suse.de
- initial package version 1.1.3
